==> tuia-advert-center-api-1.5.0-20180621.153018-4-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/app/RspAppSimpleInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.app;

import java.io.Serializable;

/**
 * Created by 李志辉 on 2017-07-07 16:34.
 */
public class RspAppSimpleInfoDto implements Serializable {
    private Long appId;
    private String appName;
    private String tagName;
    private Integer appSource;
    private Integer appStatus;//媒体状态，0：无效，1：有效
    private String appAccount;

    /**
     * 昨日发券量
     */
    private Long yesterLaunch;

    /**
     * 昨日cvr
     */
    private Double yesterdayCVR;

    public Integer getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(Integer appStatus) {
        this.appStatus = appStatus;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public String getAppAccount() {
        return appAccount;
    }

    public void setAppAccount(String appAccount) {
        this.appAccount = appAccount;
    }

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    public Long getYesterLaunch() {
        return yesterLaunch;
    }

    public void setYesterLaunch(Long yesterLaunch) {
        this.yesterLaunch = yesterLaunch;
    }

    public Double getYesterdayCVR() {
        return yesterdayCVR;
    }

    public void setYesterdayCVR(Double yesterdayCVR) {
        this.yesterdayCVR = yesterdayCVR;
    }
}

==> tuia-advert-center-api-1.7.7-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/app/RspAppSimpleInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.app;

import java.io.Serializable;

/**
 * Created by 李志辉 on 2017-07-07 16:34.
 */
public class RspAppSimpleInfoDto implements Serializable {
    private static final long serialVersionUID = 2325092657597697527L;
    private Long appId;
    private String appName;
    private String tagName;
    private Integer appSource;
    private Integer appStatus;//媒体状态，0：无效，1：有效
    private String appAccount;

    /**
     * 昨日发券量
     */
    private Long yesterLaunch;

    /**
     * 昨日cvr
     */
    private Double yesterdayCVR;

    /**
     *预估发券量
     */
    private Integer estimate;

    public Integer getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(Integer appStatus) {
        this.appStatus = appStatus;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public String getAppAccount() {
        return appAccount;
    }

    public void setAppAccount(String appAccount) {
        this.appAccount = appAccount;
    }

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    public Long getYesterLaunch() {
        return yesterLaunch;
    }

    public void setYesterLaunch(Long yesterLaunch) {
        this.yesterLaunch = yesterLaunch;
    }

    public Double getYesterdayCVR() {
        return yesterdayCVR;
    }

    public void setYesterdayCVR(Double yesterdayCVR) {
        this.yesterdayCVR = yesterdayCVR;
    }

    public Integer getEstimate() {
        return estimate;
    }

    public void setEstimate(Integer estimate) {
        this.estimate = estimate;
    }
}
